# 文档翻译改进建议 感谢您对本项目的关注！非英文文档由大语言模型自动翻译，因此错误在所难免。如果您在熟悉的语言中发现问题，我们热忱欢迎您提出改进建议。 在开始贡献之前，请花点时间阅读以下指南，以确保您的建议能够顺利被采纳。 # 通过 Weblate 提交建议 我们使用 [Weblate](https://weblate.org/) 来管理我们的文档翻译。您可以在 [项目的 Weblate 页面](https://hosted.weblate.org/projects/pdfmathtranslate-next/) 上查看当前的翻译状态并提交建议。 ## 如何提交建议 通过 Weblate 提出翻译改进建议非常简单，甚至无需注册账户。请继续阅读以下指南。 假设您想改进 [高级选项 → 高级](docs/en/advanced/advanced.md) 中 "命令行参数" 部分的第一个句子： 1. 打开 [项目的 Weblate 页面](https://hosted.weblate.org/projects/pdfmathtranslate-next/)。 2. 点击顶部的 `Search`。 3. 在「Filter」中输入您想要查找的文本片段，部分文本即可。 完成后，按 `Enter`。 4. 按下 `Enter` 后，您将被带到搜索结果页面。点击您偏好的结果以打开编辑视图。 5. 在编辑视图中，对翻译进行修改。完成后，点击 `Suggest`。就这样——您已成功完成一次贡献。 我们会在您提交建议后进行审核。一旦通过，您的修改将出现在文档中。

###### 本页面的部分内容由 GPT 翻译，可能包含错误。